package javax.imageio.spi;

import java.util.Iterator;
import java.util.HashMap;
import java.util.Set;
import java.util.Map;
import java.util.AbstractSet;

class PartiallyOrderedSet extends AbstractSet
{
    private Map poNodes;
    private Set nodes;
    
    public PartiallyOrderedSet() {
        this.poNodes = new HashMap();
        this.nodes = this.poNodes.keySet();
    }
    
    @Override
    public int size() {
        return this.nodes.size();
    }
    
    @Override
    public boolean contains(Object o) {
        return this.nodes.contains(o);
    }
    
    @Override
    public Iterator iterator() {
        return new PartialOrderIterator(this.poNodes.values().iterator());
    }
    
    @Override
    public boolean add(Object o) {
        if (this.nodes.contains(o)) {
            return false;
        }
        this.poNodes.put(o, new DigraphNode(o));
        return true;
    }
    
    @Override
    public boolean remove(Object o) {
        DigraphNode digraphNode = (DigraphNode)this.poNodes.get(o);
        if (digraphNode == null) {
            return false;
        }
        this.poNodes.remove(o);
        digraphNode.dispose();
        return true;
    }
    
    @Override
    public void clear() {
        this.poNodes.clear();
    }
    
    public boolean setOrdering(Object o, Object o2) {
        DigraphNode digraphNode = (DigraphNode)this.poNodes.get(o);
        DigraphNode digraphNode2 = (DigraphNode)this.poNodes.get(o2);
        digraphNode2.removeEdge(digraphNode);
        return digraphNode.addEdge(digraphNode2);
    }
    
    public boolean unsetOrdering(Object o, Object o2) {
        DigraphNode digraphNode = (DigraphNode)this.poNodes.get(o);
        DigraphNode digraphNode2 = (DigraphNode)this.poNodes.get(o2);
        return digraphNode.removeEdge(digraphNode2) || digraphNode2.removeEdge(digraphNode);
    }
    
    public boolean hasOrdering(Object o, Object o2) {
        return ((DigraphNode)this.poNodes.get(o)).hasEdge((DigraphNode)this.poNodes.get(o2));
    }
}
